# Generated by Django 2.2.2 on 2020-03-18 17:06

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Mail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(editable=False, verbose_name='Created')),
                ('updated', models.DateTimeField(editable=False, verbose_name='Updated')),
                ('subject', models.CharField(blank=True, max_length=250, verbose_name='Subject')),
                ('to_address', models.TextField(verbose_name='To')),
                ('cc_address', models.TextField(blank=True, verbose_name='CC')),
                ('bcc_address', models.TextField(blank=True, verbose_name='BCC')),
                ('from_address', models.EmailField(max_length=250, verbose_name='From')),
                ('content', models.TextField(blank=True, verbose_name='Content')),
                ('html_content', models.TextField(blank=True, verbose_name='HTML Content')),
                ('errors', models.TextField(blank=True, default='', verbose_name='Content')),
                ('sent', models.DateTimeField(blank=True, null=True)),
            ],
            options={
                'ordering': ['updated'],
                'abstract': False,
            },
        ),
    ]
